summaryrefslogtreecommitdiff
path: root/src/cache.hpp
diff options
context:
space:
mode:
authorCedric Nugteren <web@cedricnugteren.nl>2017-10-29 20:01:30 +0100
committerCedric Nugteren <web@cedricnugteren.nl>2017-10-29 20:01:30 +0100
commitac5a58cfe5d2fad1ef248c619ad68611dcabcfc7 (patch)
tree41bc3ee816dd6cd56c958c52e2dcfb1af889cd1a /src/cache.hpp
parent19c53f6dd06e1fc2b3f71ab738bd97af070fe627 (diff)
Added platform ID to the binary program cache to prevent issues with multi-platform systems
Diffstat (limited to 'src/cache.hpp')
-rw-r--r--src/cache.hpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/cache.hpp b/src/cache.hpp
index 1c8c9d4c..228fbccb 100644
--- a/src/cache.hpp
+++ b/src/cache.hpp
@@ -66,10 +66,10 @@ private:
// =================================================================================================
// The key struct for the cache of compiled OpenCL binaries
// Order of fields: precision, routine_name, device_name (smaller fields first)
-typedef std::tuple<Precision, std::string, std::string> BinaryKey;
-typedef std::tuple<const Precision &, const std::string &, const std::string &> BinaryKeyRef;
+typedef std::tuple<RawPlatformID, Precision, std::string, std::string> BinaryKey;
+typedef std::tuple<const RawPlatformID &, const Precision &, const std::string &, const std::string &> BinaryKeyRef;
typedef Cache<BinaryKey, std::string> BinaryCache;
@@ -66,10 +66,10 @@ private:
// =================================================================================================
-// The key struct for the cache of compiled OpenCL binaries
+// The key struct for the cache of compiled OpenCL binaries (device name and platform-dependent)
// Order of fields: precision, routine_name, device_name (smaller fields first)